.. aiodiscqueue documentation master file, created by
   sphinx-quickstart on Wed May 24 16:44:01 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
    :hidden:
    :maxdepth: 4

    api

---------------------------

Contents
--------

.. toctree::
    :maxdepth: 2

    api
